=======================
Configuration Reference
=======================

This section provides a list of all configuration options for various neutron
services. These are auto-generated from neutron code when this documentation is
built.

Configuration filenames used below are filenames usually used, but there
is no restriction on configuration filename in neutron and you can use
arbitrary file names.

.. only:: html

   For sample configuration files, refer to :doc:`config-samples`.

   .. toctree::
      :hidden:

      config-samples

.. toctree::
   :maxdepth: 1

   neutron.rst

.. toctree::
   :maxdepth: 1

   ml2-conf.rst
   linuxbridge-agent.rst
   macvtap-agent.rst
   openvswitch-agent.rst
   sriov-agent.rst

.. toctree::
   :maxdepth: 1

   dhcp-agent.rst
   l3-agent.rst
   metadata-agent.rst
   metering-agent.rst
